"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFhirFetch = void 0;

var _object = require("./object");

// @ts-check

/**
 * Get a configured fetcher for FHIR requests
 *
 * @param {{
 *   apiUrl: string
 *   getToken: () => string
 *   getOrgId: () => string
 * }} options
 * @returns {(pathname: string, opts?: { orgId?: string }) => Promise} Opts
 */
const getFhirFetch = options => {
  const {
    getToken,
    getOrgId,
    apiUrl
  } = options;
  return (relative, opts = {}) => {
    const [pathname, query] = relative.split('?');
    const tokenAddon = "token=".concat(getToken());
    const modifiedQueryString = query ? "".concat(query, "&").concat(tokenAddon) : tokenAddon;
    const orgId = opts.orgId || getOrgId();
    const fetchOptions = (0, _object.omit)(opts, ['orgId']);

    if (!orgId) {
      throw Error('NO_ORG_ID');
    }

    const base = "".concat(apiUrl, "/fhir/").concat(orgId);
    return fetch("".concat(base).concat(pathname, "?").concat(modifiedQueryString), fetchOptions).then(res => {
      if (res.status >= 400) {
        if (res.status === 404) {
          throw Error('NOT_FOUND');
        } else if (res.status === 403 || res.status === 401) {
          throw Error('NOT_PERMITTED');
        } else if (res.status === 409) {
          throw Error('CONFLICT');
        } else {
          throw Error('REQUEST_ERROR_' + res.status);
        }
      }

      return res.json();
    });
  };
};

exports.getFhirFetch = getFhirFetch;